Index: du.1
===================================================================
RCS file: /usr/CVS-Repository/src/usr.bin/du/du.1,v
retrieving revision 1.32
diff -u -r1.32 du.1
--- du.1	29 Sep 2006 15:20:44 -0000	1.32
+++ du.1	2 Sep 2008 00:55:18 -0000
@@ -42,7 +42,7 @@
 .Nm
 .Op Fl H | L | P
 .Op Fl a | s | d Ar depth
-.Op Fl c
+.Op Fl b c
 .Op Fl h | k | m
 .Op Fl n
 .Op Fl x
@@ -72,6 +72,8 @@
 This is the default.
 .It Fl a
 Display an entry for each file in a file hierarchy.
+.It Fl b
+Count the apparent file size (rather than blocks used)
 .It Fl h
 "Human-readable" output.
 Use unit suffixes: Byte, Kilobyte, Megabyte,
Index: du.c
===================================================================
RCS file: /usr/CVS-Repository/src/usr.bin/du/du.c,v
retrieving revision 1.42
diff -u -r1.42 du.c
--- du.c	4 Jul 2007 00:00:39 -0000	1.42
+++ du.c	2 Sep 2008 00:51:13 -0000
@@ -90,20 +90,20 @@
 	int		ftsoptions;
 	int		listall;
 	int		depth;
-	int		Hflag, Lflag, Pflag, aflag, sflag, dflag, cflag, hflag, ch, notused, rval;
+	int		Hflag, Lflag, Pflag, aflag, bflag, sflag, dflag, cflag, hflag, ch, notused, rval;
 	char 		**save;
 	static char	dot[] = ".";
 
 	setlocale(LC_ALL, "");
 
-	Hflag = Lflag = Pflag = aflag = sflag = dflag = cflag = hflag = 0;
+	Hflag = Lflag = Pflag = aflag = bflag = sflag = dflag = cflag = hflag = 0;
 
 	save = argv;
 	ftsoptions = 0;
 	depth = INT_MAX;
 	SLIST_INIT(&ignores);
 
-	while ((ch = getopt(argc, argv, "HI:LPasd:chkmnrx")) != -1)
+	while ((ch = getopt(argc, argv, "HI:LPabsd:chkmnrx")) != -1)
 		switch (ch) {
 			case 'H':
 				Hflag = 1;
@@ -124,6 +124,9 @@
 			case 'a':
 				aflag = 1;
 				break;
+			case 'b':
+				bflag = 1;
+				break;
 			case 's':
 				sflag = 1;
 				break;
@@ -231,8 +234,12 @@
 				if (ignorep(p))
 					break;
 
-				p->fts_parent->fts_bignum +=
-				    p->fts_bignum += p->fts_statp->st_blocks;
+				if (bflag)
+					p->fts_parent->fts_bignum +=
+						p->fts_bignum += p->fts_statp->st_size / 512;
+				else
+				    p->fts_parent->fts_bignum +=
+				    	p->fts_bignum += p->fts_statp->st_blocks;
 
 				if (p->fts_level <= depth) {
 					if (hflag) {
@@ -262,17 +269,29 @@
 
 				if (listall || p->fts_level == 0) {
 					if (hflag) {
-						(void) prthumanval(howmany(p->fts_statp->st_blocks,
-							blocksize));
+						if (bflag)
+							(void) prthumanval(howmany(p->fts_statp->st_size / 512,
+								blocksize));
+						else
+							(void) prthumanval(howmany(p->fts_statp->st_blocks,
+								blocksize));
 						(void) printf("\t%s\n", p->fts_path);
 					} else {
-						(void) printf("%jd\t%s\n",
-							(intmax_t)howmany(p->fts_statp->st_blocks, blocksize),
-							p->fts_path);
+						if (bflag)
+							(void) printf("%jd\t%s\n",
+								(intmax_t)howmany(p->fts_statp->st_size / 512,
+									blocksize), p->fts_path);
+						else
+							(void) printf("%jd\t%s\n",
+								(intmax_t)howmany(p->fts_statp->st_blocks,
+									blocksize), p->fts_path);
 					}
 				}
 
-				p->fts_parent->fts_bignum += p->fts_statp->st_blocks;
+				if (bflag)
+					p->fts_parent->fts_bignum += p->fts_statp->st_size / 512;
+				else
+					p->fts_parent->fts_bignum += p->fts_statp->st_blocks;
 		}
 		savednumber = p->fts_parent->fts_bignum;
 	}
@@ -443,7 +462,7 @@
 usage(void)
 {
 	(void)fprintf(stderr,
-		"usage: du [-H | -L | -P] [-a | -s | -d depth] [-c] [-h | -k | -m] [-n] [-x] [-I mask] [file ...]\n");
+		"usage: du [-H | -L | -P] [-a | -s | -d depth] [-b] [-c] [-h | -k | -m] [-n] [-x] [-I mask] [file ...]\n");
 	exit(EX_USAGE);
 }
 
